## $Id: fileviewlets.py 12557 2015-02-03 17:38:21Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.ikoba.interfaces import MessageFactory as _
from waeup.ikoba.customers.interfaces import ICustomer
from waeup.ikoba.browser.fileviewlets import (
    FileDisplay, FileUpload, Image)

from ikobacustom.pcn.customers.documents import (
    PCNCustomerJPGDocument, PCNCustomerPDFDocument)

from waeup.ikoba.customers.browser import (
    CustomerBaseDisplayFormPage,
    CustomerBaseManageFormPage,
    CustomerFilesUploadPage,
    DocumentDisplayFormPage,
    DocumentManageFormPage,
    DocumentEditFormPage,
    PDFDocumentSlipPage)

grok.templatedir('browser_templates')

# File viewlets for customer base page

class BirthCertificateDisplay(FileDisplay):
    """Birth certificate display viewlet.
    """
    grok.order(2)
    grok.context(ICustomer)
    grok.view(CustomerBaseDisplayFormPage)
    grok.require('waeup.viewCustomer')
    label = _(u'Birth Certificate')
    download_name = u'birth_certificate.pdf'
    download_filename = u'birth_certificate.pdf'


class BirthCertificateManageUpload(FileUpload):
    """Birth Certificate upload viewlet for officers.
    """
    grok.order(2)
    grok.context(ICustomer)
    grok.view(CustomerBaseManageFormPage)
    grok.require('waeup.manageCustomer')
    label = _(u'Birth Certificate (pdf only)')
    mus = 1024 * 200
    download_name = u'birth_certificate.pdf'
    download_filename = u'birth_certificate.pdf'
    tab_redirect = '#tab2'


class BirthCertificateEditUpload(BirthCertificateManageUpload):
    """Birth certificate upload viewlet for customers.
    """
    grok.view(CustomerFilesUploadPage)
    grok.require('waeup.handleCustomer')


class BirthCertificate(Image):
    """Renders pdf.
    """
    grok.name('birth_certificate.pdf')
    download_name = u'birth_certificate.pdf'
    grok.context(ICustomer)
    grok.require('waeup.viewCustomer')
    download_filename = u'birth_certificate.pdf'

class CertificatesDisplay(FileDisplay):
    """Certificates display viewlet.
    """
    grok.order(2)
    grok.context(ICustomer)
    grok.view(CustomerBaseDisplayFormPage)
    grok.require('waeup.viewCustomer')
    label = _(u'Certificates/Credentials')
    download_name = u'certificates.pdf'
    download_filename = u'certificates.pdf'


class CertificatesManageUpload(FileUpload):
    """Certificates upload viewlet for officers.
    """
    grok.order(2)
    grok.context(ICustomer)
    grok.view(CustomerBaseManageFormPage)
    grok.require('waeup.manageCustomer')
    label = _(u'Certificates/Credentials (pdf only)')
    mus = 1024 * 200
    download_name = u'certificates.pdf'
    download_filename = u'certificates.pdf'
    tab_redirect = '#tab2'


class CertificatesEditUpload(CertificatesManageUpload):
    """Certificates upload viewlet for customers.
    """
    grok.view(CustomerFilesUploadPage)
    grok.require('waeup.handleCustomer')


class Certificates(Image):
    """Renders pdf.
    """
    grok.name('certificates.pdf')
    download_name = u'certificates.pdf'
    grok.context(ICustomer)
    grok.require('waeup.viewCustomer')
    download_filename = u'certificates.pdf'

# File viewlets for customer documents

class JPGScanManageUpload(FileUpload):
    """Scan upload viewlet for officers.
    """
    grok.order(1)
    grok.context(PCNCustomerJPGDocument)
    grok.view(DocumentManageFormPage)
    grok.require('waeup.manageCustomer')
    label = _(u'Sample Scan')
    title = _(u'Sample Scan')
    mus = 1024 * 200
    download_name = u'scan.jpg'
    tab_redirect = '#tab2'

    @property
    def download_filename(self):
        return u"%s.jpg" % self.context.document_id[:9]


class JPGScanEditUpload(JPGScanManageUpload):
    """Scan upload viewlet for customer.
    """
    grok.view(DocumentEditFormPage)
    grok.require('waeup.handleCustomer')


class JPGScanDisplay(FileDisplay):
    """Scan display viewlet.
    """
    grok.order(1)
    grok.context(PCNCustomerJPGDocument)
    grok.require('waeup.viewCustomer')
    grok.view(DocumentDisplayFormPage)
    label = _(u'Sample Scan')
    title = _(u'Sample Scan')
    download_name = u'scan.jpg'

    @property
    def download_filename(self):
        return u"%s.jpg" % self.context.document_id[:9]


class JPGScanImage(Image):
    """Scan document.
    """
    grok.name('scan.jpg')
    grok.context(PCNCustomerJPGDocument)
    grok.require('waeup.viewCustomer')
    download_name = u'scan.jpg'

    @property
    def download_filename(self):
        return u"%s.jpg" % self.context.document_id[:9]

class JPGScanPDFSlip(JPGScanDisplay):
    grok.view(PDFDocumentSlipPage)


class PDFScanManageUpload(FileUpload):
    """Scan upload viewlet for officers.
    """
    grok.view(DocumentManageFormPage)
    grok.context(PCNCustomerPDFDocument)
    grok.require('waeup.manageCustomer')
    label = _(u'PDF File')
    title = _(u'PDF File')
    mus = 1024 * 1000
    download_name = u'scan.pdf'
    tab_redirect = '#tab2'

    @property
    def download_filename(self):
        return u"%s.pdf" % self.context.document_id[:9]


class PDFScanEditUpload(PDFScanManageUpload):
    """Scan upload viewlet for customer.
    """
    grok.view(DocumentEditFormPage)
    grok.require('waeup.handleCustomer')


class PDFScanDisplay(FileDisplay):
    """Scan display viewlet.
    """
    grok.order(1)
    grok.context(PCNCustomerPDFDocument)
    grok.require('waeup.viewCustomer')
    grok.view(DocumentDisplayFormPage)
    label = _(u'PDF Scan')
    title = _(u'PDF Scan')
    download_name = u'scan.pdf'

    @property
    def download_filename(self):
        return u"%s.pdf" % self.context.document_id[:9]


class PDFScanImage(Image):
    """Scan document.
    """
    grok.name('scan.pdf')
    grok.context(PCNCustomerPDFDocument)
    grok.require('waeup.viewCustomer')
    download_name = u'scan.pdf'

    @property
    def download_filename(self):
        return u"%s" % self.context.document_id[:9]

class PDFScanSlip(PDFScanDisplay):
    grok.view(PDFDocumentSlipPage)
